'use strict';

var _ = require('lodash');

module.exports = {
    packageJson: function packageJson() {
        this.appendPackageJson({
            name: _.kebabCase(this.props.name),
            version: this.props.version,
            description: this.props.description,
            homepage: this.props.homepage,
            scripts: {},
            repository: {
                type: 'git',
                url: 'https://github.com/' + this.props.repository
            },
            bugs: {
                url: 'https://github.com/' + this.props.repository + '/issues'
            },
            author: {
                name: this.props.authorName,
                email: this.props.authorEmail,
                url: this.props.authorUrl
            },
            files: ['client'],
            keywords: this.props.keywords
        });
    },

    writeTemplates: function writeTemplates() {
        // Do Nothing
    },

    subgenerators: function subgenerators() {
        var _this = this;

        var composeLocal = function composeLocal(name) {
            _this.composeWith('ats-node-webapp:' + name, { options: _this.props }, { local: require.resolve('../../' + name) });
        };
        var useOAuthStrategy = function useOAuthStrategy(name) {
            return (_this.props.oauthStrategies || []).indexOf(name) > -1;
        };
        this.props.useOAuthStrategy = useOAuthStrategy;

        composeLocal('git');
        composeLocal('git-hooks');
        composeLocal('editorconfig');
        composeLocal('eslint');
        composeLocal('readme');
        composeLocal('app-symlink');
        composeLocal('server');
        composeLocal('docker-compose');
        composeLocal('client-assets');
        composeLocal('client-styles');
        composeLocal('client-build');
        composeLocal('gulp');

        if (useOAuthStrategy('facebook')) {
            composeLocal('auth-facebook');
        }
        if (useOAuthStrategy('github')) {
            composeLocal('auth-github');
        }
        if (useOAuthStrategy('google')) {
            composeLocal('auth-google');
        }
        if (useOAuthStrategy('twitter')) {
            composeLocal('auth-twitter');
        }

        if (this.props.client === 'react') {
            composeLocal('client-react');
        } else if (this.props.client === 'angular') {
            composeLocal('client-angular');
        }

        composeLocal('gulp-postinstall');
    }
};